==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/SootCodeGenerator.h <==
// public class org.dellroad.jc.cgen.SootCodeGenerator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class db0e47565c537acd org_dellroad_jc_cgen_SootCodeGenerator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_SootCodeGenerator_H_
#define _JC_org_dellroad_jc_cgen_SootCodeGenerator_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_dellroad_jc_ClassfileFinder$object;
struct _jc_org_dellroad_jc_cgen_MethodOptimizer$object;
struct _jc_org_dellroad_jc_cgen_SourceLocator$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$sub_refs	_jc_org_dellroad_jc_cgen_SootCodeGenerator$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$sub_nonrefs	_jc_org_dellroad_jc_cgen_SootCodeGenerator$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$refs	_jc_org_dellroad_jc_cgen_SootCodeGenerator$refs;
typedef struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$nonrefs	_jc_org_dellroad_jc_cgen_SootCodeGenerator$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object	_jc_org_dellroad_jc_cgen_SootCodeGenerator$object;

typedef struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$fields_struct	_jc_org_dellroad_jc_cgen_SootCodeGenerator$fields_struct;
typedef const struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$vmethods	_jc_org_dellroad_jc_cgen_SootCodeGenerator$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$vtable	_jc_org_dellroad_jc_cgen_SootCodeGenerator$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$vtype	_jc_org_dellroad_jc_cgen_SootCodeGenerator$vtype;

// Class fields structure
struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$fields_struct {
	struct _jc_java_lang_String$object	*DEFAULT__5fMETHOD__5fOPTIMIZER;
	struct _jc_object	*finder;
};
extern _jc_org_dellroad_jc_cgen_SootCodeGenerator$fields_struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$class_fields;

// Constructors
extern void _jc_org_dellroad_jc_cgen_SootCodeGenerator$method$_init$29f981702f45d42a(_jc_env *, struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object *, struct _jc_org_dellroad_jc_cgen_SourceLocator$object *, struct _jc_object *, jboolean);

// Virtual methods
extern void _jc_org_dellroad_jc_cgen_SootCodeGenerator$method$genC$e930a2f14c2cc8f9(_jc_env *, struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object *, struct _jc_java_lang_String$object *, struct _jc_java_io_OutputStream$object *);
extern void _jc_org_dellroad_jc_cgen_SootCodeGenerator$method$genH$8b8d185eda1247cb(_jc_env *, struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object *, struct _jc_java_lang_String$object *, struct _jc_java_io_OutputStream$object *);
extern void _jc_org_dellroad_jc_cgen_SootCodeGenerator$method$generateC$62c1165ed4dfad41(_jc_env *, struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_java_io_OutputStream$object *);
extern void _jc_org_dellroad_jc_cgen_SootCodeGenerator$method$generateH$7ab3bf8c65d9a6c1(_jc_env *, struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_java_io_OutputStream$object *);
extern void _jc_org_dellroad_jc_cgen_SootCodeGenerator$method$reset$229a80b3e8394a0f(_jc_env *, struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_SootCodeGenerator$method_info$genC$e930a2f14c2cc8f9;
extern _jc_method _jc_org_dellroad_jc_cgen_SootCodeGenerator$method_info$genH$8b8d185eda1247cb;
extern _jc_method _jc_org_dellroad_jc_cgen_SootCodeGenerator$method_info$generateC$62c1165ed4dfad41;
extern _jc_method _jc_org_dellroad_jc_cgen_SootCodeGenerator$method_info$generateH$7ab3bf8c65d9a6c1;
extern _jc_method _jc_org_dellroad_jc_cgen_SootCodeGenerator$method_info$reset$229a80b3e8394a0f;

// Static methods
extern void _jc_org_dellroad_jc_cgen_SootCodeGenerator$method$setField$6c5fc6fdbddc8b38(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *);

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$vmethods {
	void	(*genC$e930a2f14c2cc8f9)(_jc_env *, struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object *, struct _jc_java_lang_String$object *, struct _jc_java_io_OutputStream$object *);
	void	(*genH$8b8d185eda1247cb)(_jc_env *, struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object *, struct _jc_java_lang_String$object *, struct _jc_java_io_OutputStream$object *);
	void	(*generateC$62c1165ed4dfad41)(_jc_env *, struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_java_io_OutputStream$object *);
	void	(*generateH$7ab3bf8c65d9a6c1)(_jc_env *, struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_java_io_OutputStream$object *);
	void	(*reset$229a80b3e8394a0f)(_jc_env *, struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object *);
};

// Vtable
struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_SootCodeGenerator$vmethods	org_dellroad_jc_cgen_SootCodeGenerator;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_SootCodeGenerator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$sub_refs {
	struct _jc_org_dellroad_jc_cgen_SourceLocator$object	*sourceLocator;
	struct _jc_object	*optimizer;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$refs {
    _jc_org_dellroad_jc_cgen_SootCodeGenerator$sub_refs	org_dellroad_jc_cgen_SootCodeGenerator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$sub_nonrefs {
	jboolean	includeLineNumbers;
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_SootCodeGenerator$sub_nonrefs	org_dellroad_jc_cgen_SootCodeGenerator;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object {
	_jc_org_dellroad_jc_cgen_SootCodeGenerator$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_SootCodeGenerator$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_SootCodeGenerator$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_SootCodeGenerator$vtype _jc_org_dellroad_jc_cgen_SootCodeGenerator$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_SootCodeGenerator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_SootCodeGenerator$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_SootCodeGenerator_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/SootCodeGenerator.h <==
// public class org.dellroad.jc.cgen.SootCodeGenerator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class db0e47565c537acd org_dellroad_jc_cgen_SootCodeGenerator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_SootCodeGenerator_H_
#define _JC_org_dellroad_jc_cgen_SootCodeGenerator_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_dellroad_jc_ClassfileFinder$object;
struct _jc_org_dellroad_jc_cgen_MethodOptimizer$object;
struct _jc_org_dellroad_jc_cgen_SourceLocator$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$sub_refs	_jc_org_dellroad_jc_cgen_SootCodeGenerator$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$sub_nonrefs	_jc_org_dellroad_jc_cgen_SootCodeGenerator$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$refs	_jc_org_dellroad_jc_cgen_SootCodeGenerator$refs;
typedef struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$nonrefs	_jc_org_dellroad_jc_cgen_SootCodeGenerator$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object	_jc_org_dellroad_jc_cgen_SootCodeGenerator$object;

typedef struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$fields_struct	_jc_org_dellroad_jc_cgen_SootCodeGenerator$fields_struct;
typedef const struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$vmethods	_jc_org_dellroad_jc_cgen_SootCodeGenerator$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$vtable	_jc_org_dellroad_jc_cgen_SootCodeGenerator$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$vtype	_jc_org_dellroad_jc_cgen_SootCodeGenerator$vtype;

// Class fields structure
struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$fields_struct {
	struct _jc_java_lang_String$object	*DEFAULT__5fMETHOD__5fOPTIMIZER;
	struct _jc_object	*finder;
};
extern _jc_org_dellroad_jc_cgen_SootCodeGenerator$fields_struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$class_fields;

// Constructors
extern void _jc_org_dellroad_jc_cgen_SootCodeGenerator$method$_init$29f981702f45d42a(_jc_env *, struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object *, struct _jc_org_dellroad_jc_cgen_SourceLocator$object *, struct _jc_object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_org_dellroad_jc_cgen_SootCodeGenerator$method$genC$e930a2f14c2cc8f9(_jc_env *, struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object *, struct _jc_java_lang_String$object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_SootCodeGenerator$method$genH$8b8d185eda1247cb(_jc_env *, struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object *, struct _jc_java_lang_String$object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_SootCodeGenerator$method$generateC$62c1165ed4dfad41(_jc_env *, struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_SootCodeGenerator$method$generateH$7ab3bf8c65d9a6c1(_jc_env *, struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_SootCodeGenerator$method$reset$229a80b3e8394a0f(_jc_env *, struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_SootCodeGenerator$method_info$genC$e930a2f14c2cc8f9;
extern _jc_method _jc_org_dellroad_jc_cgen_SootCodeGenerator$method_info$genH$8b8d185eda1247cb;
extern _jc_method _jc_org_dellroad_jc_cgen_SootCodeGenerator$method_info$generateC$62c1165ed4dfad41;
extern _jc_method _jc_org_dellroad_jc_cgen_SootCodeGenerator$method_info$generateH$7ab3bf8c65d9a6c1;
extern _jc_method _jc_org_dellroad_jc_cgen_SootCodeGenerator$method_info$reset$229a80b3e8394a0f;

// Static methods
extern void _jc_org_dellroad_jc_cgen_SootCodeGenerator$method$setField$6c5fc6fdbddc8b38(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$vmethods {
	void	(*genC$e930a2f14c2cc8f9)(_jc_env *, struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object *, struct _jc_java_lang_String$object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;
	void	(*genH$8b8d185eda1247cb)(_jc_env *, struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object *, struct _jc_java_lang_String$object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;
	void	(*generateC$62c1165ed4dfad41)(_jc_env *, struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;
	void	(*generateH$7ab3bf8c65d9a6c1)(_jc_env *, struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;
	void	(*reset$229a80b3e8394a0f)(_jc_env *, struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_SootCodeGenerator$vmethods	org_dellroad_jc_cgen_SootCodeGenerator;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_SootCodeGenerator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$sub_refs {
	struct _jc_org_dellroad_jc_cgen_SourceLocator$object	*sourceLocator;
	struct _jc_object	*optimizer;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$refs {
    _jc_org_dellroad_jc_cgen_SootCodeGenerator$sub_refs	org_dellroad_jc_cgen_SootCodeGenerator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$sub_nonrefs {
	jboolean	includeLineNumbers;
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_SootCodeGenerator$sub_nonrefs	org_dellroad_jc_cgen_SootCodeGenerator;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_SootCodeGenerator$object {
	_jc_org_dellroad_jc_cgen_SootCodeGenerator$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_SootCodeGenerator$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_SootCodeGenerator$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_SootCodeGenerator$vtype _jc_org_dellroad_jc_cgen_SootCodeGenerator$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_SootCodeGenerator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_SootCodeGenerator$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_SootCodeGenerator_H_ */
